import chalk from "chalk";
import { allArgOptions } from "../shared/options/args.js";
function logHelpTextSection(section) {
  console.log(" ");
  console.log(`${chalk.black.bgGreenBright(section.sectionHeading)}`);
  for (const subsection of section.subsections) {
    if (subsection.warning) {
      console.log(chalk.yellow(subsection.warning));
    }
    if (subsection.subheading) {
      console.log(chalk.green(subsection.subheading));
    }
    for (const { description, flag, type } of subsection.flags) {
      console.log(
        chalk.cyan(
          `
  --${flag}${type !== "boolean" ? ` (${chalk.cyanBright(type)})` : ""}: ${description}`
        )
      );
    }
  }
}
function createHelpTextSections() {
  const core = {
    sectionHeading: "Core options:",
    subsections: [
      {
        flags: []
      }
    ]
  };
  const optional = {
    sectionHeading: "Optional options:",
    subsections: [
      {
        flags: []
      }
    ]
  };
  const optOut = {
    sectionHeading: "Opt-outs:",
    subsections: [
      {
        flags: [],
        warning: `
  \u26A0\uFE0F Warning: Specifying any --exclude-* flag on the command-line will 
  cause the setup script to skip prompting for more excludes. \u26A0\uFE0F`
      },
      {
        flags: [
          {
            description: `Skips network calls that fetch all-contributors
  data from GitHub`,
            flag: "exclude-contributors",
            type: "boolean"
          }
        ],
        subheading: `
You can prevent the migration script from making some network-based 
changes using any or all of the following CLI flags:`
      },
      {
        flags: [],
        subheading: `
You can prevent the migration script from making some changes on disk 
using any or all of the following CLI flags:`
      }
    ]
  };
  const offline = {
    sectionHeading: "Offline Mode:",
    subsections: [
      {
        flags: []
      }
    ]
  };
  const subsections = {
    core: core.subsections[0],
    offline: offline.subsections[0],
    "opt-out": optOut.subsections[0],
    optional: optional.subsections[0],
    "skip-disk": optOut.subsections[2],
    "skip-net": optOut.subsections[1]
  };
  for (const [option, data] of Object.entries(allArgOptions)) {
    subsections[data.docsSection].flags.push({
      description: data.description,
      flag: option,
      type: data.type
    });
  }
  return [core, optional, optOut, offline];
}
function logHelpText(introLogs) {
  const helpTextSections = createHelpTextSections();
  for (const log of introLogs) {
    console.log(log);
    console.log(" ");
  }
  console.log(
    chalk.cyan(
      `
A quickstart-friendly TypeScript template with comprehensive formatting, 
linting, releases, testing, and other great tooling built-in.
      `
    )
  );
  for (const section of helpTextSections) {
    logHelpTextSection(section);
    console.log();
  }
}
export {
  logHelpText
};
//# sourceMappingURL=help.js.map