import fs from "node:fs/promises";
import prettier from "prettier";
import { getGitHubUserAsAllContributor } from "../shared/getGitHubUserAsAllContributor.js";
import { readFileAsJson } from "../shared/readFileAsJson.js";
async function addOwnerAsAllContributor(options) {
  const user = await getGitHubUserAsAllContributor(options);
  const existingContributors = await readFileAsJson(
    "./.all-contributorsrc"
  );
  if (!isValidAllContributorsData(existingContributors)) {
    throw new Error(
      `Invalid .all-contributorsrc: ${JSON.stringify(existingContributors)}`
    );
  }
  const contributors = existingContributors.contributors.filter(({ login }) => ["JoshuaKGoldberg", user].includes(login)).map(
    (contributor) => contributor.login === "JoshuaKGoldberg" ? { ...contributor, contributions: ["tool"] } : {
      ...contributor,
      contributions: Array.from(
        /* @__PURE__ */ new Set([...contributor.contributions, "tool"])
      )
    }
  );
  if (!contributors.some((contributor) => contributor.login === user)) {
    contributors.push({
      contributions: ["tool"],
      login: user
    });
  }
  await fs.writeFile(
    "./.all-contributorsrc",
    await prettier.format(
      JSON.stringify({
        ...existingContributors,
        contributors
      }),
      { parser: "json" }
    )
  );
}
function isValidAllContributorsData(value) {
  return !!value && typeof value === "object" && "contributors" in value;
}
export {
  addOwnerAsAllContributor
};
//# sourceMappingURL=addOwnerAsAllContributor.js.map